from __future__ import division, print_function, absolute_import

# Constants
kb = 1.3806488e-23 # [J/K] Boltzman's constant
Na = 6.022142e23  # [mol-1] Avogrado's Number

R = 83.14        #[bar cm3 mol-1 K-1] Ideal gas constant
r = 0.083144703523     # [bar L mol-1 K-1] Ideal gas constant

